pub struct DenyMessage {
pub message: String,
}Expand description
The explicit form of a DenySpec: the model-visible message.
Fields
message: StringTrait Implementations
Sourceimpl Clone for DenyMessage
impl Clone for DenyMessage
Sourcefn clone(&self) -> DenyMessage
fn clone(&self) -> DenyMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DenyMessage
impl Debug for DenyMessage
Sourceimpl<'de> Deserialize<'de> for DenyMessage
impl<'de> Deserialize<'de> for DenyMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DenyMessage
Sourceimpl JsonSchema for DenyMessage
impl JsonSchema for DenyMessage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DenyMessage
impl PartialEq for DenyMessage
Sourcefn eq(&self, other: &DenyMessage) -> bool
fn eq(&self, other: &DenyMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DenyMessage
impl Serialize for DenyMessage
impl StructuralPartialEq for DenyMessage