pub struct Runner<'a> { /* private fields */ }Expand description
Runs test cases against a provider using a configuration.
Implementations
Sourceimpl<'a> Runner<'a>
impl<'a> Runner<'a>
Sourcepub fn run_all(&self, cases: &[TestCase]) -> Result<Report>
pub fn run_all(&self, cases: &[TestCase]) -> Result<Report>
Run every supplied case across the full platform × model matrix and
collect a Report.
Errors
Propagates the first crate::Error from loading a skill or a provider
failure. Eval failures are not errors — they are recorded in the report.